@@ -79,15 +79,15 @@ def SegmentTile(tile, background, pin_size=25, threshold_method='otsu'):
         edges_center = edges[35:-35,35:-35]
         hough_radii = np.arange(pin_size,pin_size+10, 1)
         hough_res = hough_circle(edges_center, hough_radii)
-        centers = [] 
-        accums = [] 
-        radii = []
+        centers = [None]*len(hough_radii) 
+        accums = [None]*len(hough_radii) 
+        radii = [None]*len(hough_radii)
         for radius, h in zip(hough_radii, hough_res):
             # For each radius, extract one circle
             peaks = peak_local_max(h, num_peaks=1, min_distance=25)
-            centers.extend(peaks)
-            accums.extend(h[peaks[:, 0],peaks[:,1]])
-            radii.extend([radius])
+            centers[i] = peaks.tolist()[0]
+            accums[i] = h[peaks[:, 0],peaks[:,1]].tolist()[0]
+            radii[i] = radius
             
         # Consider Likelihood of candidate circles.
         if np.max(accums) <= 0.42: # change tile to blank if circles all less than 42%
@@ -194,25 +194,23 @@ def BuildDF(tiles,masks,features ='all',save=True):
     
     positions = ([x+y for x in ['A','B','C','D','E','F','G','H'] 
             for y in ['1','2','3','4','5','6','7','8','9','10','11','12']])    
-    data = []
+    data = [None]*len(tiles)
     if features == 'all':
         features = (['Position','Area','AvgInt','PixelSum', 'Background', 'Perimeter','Variance', 'Complexity',
                     'LBP1', 'LBP2','LBP3','LBP4','LBP5','LBP6','LBP7','LBP8','LBP9','LBP10'])
-        j = 0
-        for (tile,mask,position) in zip(tiles,masks,positions):
+        
+        for j, (tile,mask,position) in enumerate(zip(tiles,masks,positions)):
             size_features = SizeFeatures(tile,mask)
+            size_features.insert(0,position)
             texture_features = TextureFeatures(tile,mask)
-            for t in texture_features:
-                size_features.append(t)
-            size_features.insert(0,position)    
-            data.append(size_features.copy())
+            size_features.extend(texture_features)    
+            data[j] = size_features.copy()
     elif features == 'size':
         features = ['Position','Area','AvgInt','PixelSum', 'Background', 'Perimeter']
-        j = 0
-        for (tile,mask,position) in zip(tiles,masks,positions):
+        for j, (tile,mask,position) in enumerate(zip(tiles,masks,positions)):
             size_features = SizeFeatures(tile,mask)
             size_features.insert(0,position)    
-            data.append(size_features.copy())
+            data[j] = size_features.copy()
     else:
         print('Feature options are \"size\" or \"all\"')
                   
@@ -260,9 +258,7 @@ def ProcessImage(file, sourcefolder, outputfolder,
         print('crop_method options are Auto, Grid, or Crop')
         
     background = CalculateBackground(tiles)
-    masks = []
-    for tile in tiles:
-        masks.append(SegmentTile(tile, background, pin_size=pin_size, threshold_method='otsu'))
+    masks = [SegmentTile(tile, background, pin_size=pin_size, threshold_method='otsu') for tile in tiles]
     
     image_label_overlay = BuildSegmentedImage(image,masks,corners)
     df = BuildDF(tiles, masks, features ='all',save=True)
@@ -297,9 +293,7 @@ def Process1Image(file, sourcefolder, outputfolder,
     # -- Calculate Background value    
     background = CalculateBackground(tiles)
     # -- Segment tiles
-    masks = []
-    for tile in tiles:
-        masks.append(SegmentTile(tile, background, pin_size=pin_size, threshold_method='otsu'))
+    masks = [SegmentTile(tile, background, pin_size=pin_size, threshold_method='otsu') for tile in tiles]
     # -- Merge Segmented Plate image
     image_label_overlay = BuildSegmentedImage(image,masks,corners)
     # -- Extract Features
@@ -444,9 +438,7 @@ def ProcessImageTest(image, outputfolder,crop_method = 'Auto', crop_param = None
         print('crop_method options are Auto or Grid')
         
     background = CalculateBackground(tiles)
-    masks = []
-    for tile in tiles:
-        masks.append(SegmentTile(tile, background, pin_size=pin_size, threshold_method='otsu'))
+    masks = [SegmentTile(tile, background, pin_size=pin_size, threshold_method='otsu') for tile in tiles]
     
     image_label_overlay = BuildSegmentedImage(image,masks,corners)
     df = BuildDF(tiles, masks, features ='all',save=True)
